@@ -13,10 +13,13 @@ import gzip
 from cepy.utils import normalize, check_adjacency_matrix
 import warnings
 
+# DOTO: pip package does not install dependencies
+# TO DO: data dir too big
+
 class CE:
 
     """
-    The main cepy class for buillding and fitting the connectome embedding model
+    The main Cepy class for buildings and fitting the connectome embedding model
 
     Parameters
     ----------
@@ -29,9 +32,9 @@ class CE:
     permutations : int, optional
         Number of independent fitting iteration.
     p : float, optional
-        Return hyper parameter (see Grover & Leskovec, 2016).
+        Return hyper parameter (see [1]_).
     q : float, optional
-        In-out parameter (see Grover & Leskovec, 2016).
+        In-out parameter (see [1]_).
     weight_key : str, optional
         On weighted graphs, this is the key for the weight attribute.
     workers : int, optional
@@ -142,6 +145,9 @@ class CE:
         if 'size' not in self.word2vec_kws:
             self.word2vec_kws['size'] = self.dimensions
 
+        if 'compute_loss' not in self.word2vec_kws:
+            self.word2vec_kws['compute_loss'] = True
+
         # window, min_count, iter should be entered as separate parameters and not to [word2vec_kws] (would be ignored)
         self.word2vec_kws['window'] = window
         self.word2vec_kws['min_count'] = min_count
@@ -319,7 +325,7 @@ class CE:
         Stores the trained weight (W and W' matrices) of all fitting permutations.
 
         Extract the weights with ``get_w_permut(index, norm_flag)`` and ``get_w_mean(norm_flag)``
-        or ``get_w_apos_permut(index, norm_flag)`` and ``get_w_apos_mean(norm_flag)`. If norm_flag
+        or ``get_w_apos_permut(index, norm_flag)`` and ``get_w_apos_mean(norm_flag)``. If norm_flag
         is set to True l2 normalization would apply on each vector before extraction.
 
         '''
@@ -364,7 +370,7 @@ class CE:
 
         Examples
         --------
-        >>> #Load, align and measure the similarity among two connectome embedding:
+        >>> #Load a model and save to file:
         >>> import cepy as ce
         >>> data_path = ce.get_examples_path()
         >>> ce_subject1 = ce.load_model(data_path + '/ce_subject1.pkl.gz')
@@ -399,7 +405,7 @@ def load_model(path):
 
     Examples
     --------
-    >>> #Save and Load, and measure the similarity among two connectome embedding:
+    >>> # Save then load a model
     >>> import cepy as ce
     >>> ce_subject1 = ce.get_example('ce_subject1')
     >>> sim = ce_subject1.similarity()
